@@ -73,7 +73,7 @@ specificSettings <- function(args, new, setting, quietly = FALSE) {
 
 
 setcharacter <- function(argname, args, set = NULL, length = 1,
-                         NULL.ok = FALSE) {
+                         NULL.ok = FALSE, ignore.other = FALSE) {
   id <- argid(names(args), argname)
   ##
   if (!is.na(id)) {
@@ -84,6 +84,9 @@ setcharacter <- function(argname, args, set = NULL, length = 1,
       return(invisible(NULL))
     }
     ##
+    if (!is.character(val) & ignore.other)
+      return(invisible(id))
+    ##
     if (!is.null(set))
       val <- setchar(val, set)
     else
@@ -122,7 +125,8 @@ setlevel <- function(argname, args) {
 }
 
 
-setlogical <- function(argname, args, NULL.ok = FALSE) {
+setlogical <- function(argname, args, NULL.ok = FALSE,
+                       ignore.other = FALSE) {
   id <- argid(names(args), argname)
   ##
   if (!is.na(id)) {
@@ -133,6 +137,9 @@ setlogical <- function(argname, args, NULL.ok = FALSE) {
       return(invisible(NULL))
     }
     ##
+    if (!is.logical(val) & ignore.other)
+      return(invisible(id))
+    ##
     chklogical(val, name = argname)
     setOption(argname, val)
   }
